@@ -16,7 +16,7 @@ developmentRecordFolder="/home/gruinelli/Entwicklung/Maemo/GARAGE_SVN/Sleepanaly
 
 SongFolder="/home/user/MyDocs/.sounds"
 
-AccSensorPath="/sys/class/i2c-adapter/i2c-3/3-001d/coord"
+Acceleration_Sensor="/sys/class/i2c-adapter/i2c-3/3-001d/coord"
 
 dateformat="%Y-%m-%d %H:%M:%S" #the date/time is stored in this format in the record files
 
@@ -93,6 +93,8 @@ Deep_Sleep_Level=0
 demo=0
 debug=False
 
+StartTime=0
+
 RecordFilename=""
 RecordFile=""
 RecordFolder=""
