@@ -253,7 +253,7 @@ def ProcessAlarm():
        if(records.AlarmIsSet==True and data.AlarmIsActive==False): #alarm is set
             if(now>=records.AlarmTimeWindowStart_seconds and now<records.AlarmTimeWindowEnd_seconds): # we are in alarm time window
                 if(data.WakeUp_SongIsActive==False):#wake up song (if enabled) is not yet playing
-                    print "************ ALARM ALARM (Movement over trigger level)"
+                    print strftime("%x %X"), "************ ALARM ALARM (Movement over trigger level)"
 #                    print "*", strftime("%x %X"), "ProcessAlarm => DeleteAlarm" #for log file
 #                    data.AlarmID=DeleteAlarm(data.AlarmID) #delete old alarm if existing
                     records.AlarmTime_tuple=time.localtime()#set to now
@@ -287,9 +287,12 @@ def ProcessAlarm():
                         Alarm_successfully_set=False
                         
                     if(Alarm_successfully_set==True): #New alarm succesfully set
-                        print "New alarm got sucessfully set, now we can delete the old one"
-                        print "*", strftime("%x %X"), "ProcessAlarm => DeleteAlarm" #for log file
-                        DeleteAlarm(old_AlarmID) #delete old alarm if existing
+#                        print "New alarm got sucessfully set, now we can delete the old one"
+#                        print "*", strftime("%x %X"), "ProcessAlarm => DeleteAlarm" #for log file
+#                        DeleteAlarm(old_AlarmID) #delete old alarm if existing
+                        print "Could now delete old alarm, but are not going to do it!"
+                        print "Its a backup in case the new one does not go off or the user ignores it."
+                        print "Both alarms anyway will get deleted when the application gets closed."
                     else: #Could not set new alarm, so do not delete old alarm
                         print "!!! WARNING !!!!"
                         print "Could not set new alarm!"
@@ -306,7 +309,7 @@ def ProcessAlarm():
 
     elif(now>=records.AlarmTimeWindowEnd_seconds): #End of alarm time window, set alarm off anyway
         if(records.AlarmIsSet==True and data.AlarmIsActive==False): #Alarm is set and not active yet
-            print "************ ALARM ALARM (End of Alarm Time Window)"
+            print strftime("%x %X"), "************ ALARM ALARM (End of Alarm Time Window)"
             records.Trigger=data.Trigger #update Trigger level on alarm occurence
             data.AlarmIsActive=True
             data.Lucid_Dream_SongIsActive=True #make sure lucid dream option will not run after wake up option got active
