@@ -16,7 +16,8 @@ extern list<__ss_int> *arFiltertest, *arTest;
 extern str *__name__;
 
 __ss_bool IsCompiled();
-list<__ss_int> *sleep_filter(list<__ss_int> *ar, __ss_int l, list<__ss_int> *filter, __ss_int shift, __ss_int scale, __ss_int max, __ss_int min, __ss_int limitMovement);
+list<__ss_int> *CalculateSleepPattern(list<__ss_int> *ar, __ss_int arlen, list<__ss_int> *filter, __ss_int shift, __ss_int Yscale, __ss_int Yoffset, __ss_int Ymax, __ss_int Ymin, __ss_int limitMovement);
+list<list<__ss_int> *> *CalculateStatistic(list<__ss_int> *ar, __ss_int end_index, __ss_int TotalTime_Seconds, __ss_int Interval, __ss_int Light_Sleep_Level, __ss_int Deep_Sleep_Level);
 
 PyMODINIT_FUNC initmylib(void);
 
